@@ -15,11 +15,11 @@
 
 import sys
 
+from neutron_lib.plugins.ml2 import api
+from neutron_lib.plugins import utils as plugin_utils
 from oslo_config import cfg
 from oslo_log import log
 
-from neutron.plugins.common import utils as plugin_utils
-from neutron.plugins.ml2 import driver_api
 from neutron.plugins.ml2.drivers import type_vlan
 
 from tricircle.common import constants
@@ -44,16 +44,16 @@ class VLANTypeDriver(type_vlan.VlanTypeDriver):
     def get_type(self):
         return constants.NT_VLAN
 
-    def reserve_provider_segment(self, context, segment):
+    def reserve_provider_segment(self, context, segment, filters=None):
         res = super(VLANTypeDriver,
-                    self).reserve_provider_segment(context, segment)
-        res[driver_api.NETWORK_TYPE] = constants.NT_VLAN
+                    self).reserve_provider_segment(context, segment, filters)
+        res[api.NETWORK_TYPE] = constants.NT_VLAN
         return res
 
-    def allocate_tenant_segment(self, context):
+    def allocate_tenant_segment(self, context, filters=None):
         res = super(VLANTypeDriver,
-                    self).allocate_tenant_segment(context)
-        res[driver_api.NETWORK_TYPE] = constants.NT_VLAN
+                    self).allocate_tenant_segment(context, filters)
+        res[api.NETWORK_TYPE] = constants.NT_VLAN
         return res
 
     def get_mtu(self, physical):
