@@ -23,9 +23,13 @@ from neutron_lib.api.definitions import portbindings
 from neutron_lib.api.definitions import provider_net
 from neutron_lib.api import extensions
 from neutron_lib.api import validators
+from neutron_lib.callbacks import events
 import neutron_lib.constants as q_constants
+from neutron_lib.db import utils as db_utils
 import neutron_lib.exceptions as q_exceptions
 from neutron_lib.plugins import directory
+from neutron_lib.plugins.ml2 import api
+from neutron_lib.utils import net
 from neutron_lib.utils import runtime
 import neutronclient.client as neutronclient
 
@@ -303,7 +307,7 @@ class TricirclePlugin(plugin.Ml2Plugin):
             subnet_ids = self._ensure_subnet(context, t_network)
         if subnet_ids:
             b_network['subnets'] = subnet_ids
-        return self._fields(b_network, fields)
+        return db_utils.resource_fields(b_network, fields)
 
     def get_networks(self, context, filters=None, fields=None,
                      sorts=None, limit=None, marker=None, page_reverse=False):
@@ -322,7 +326,7 @@ class TricirclePlugin(plugin.Ml2Plugin):
             subnet_ids = self._ensure_subnet(context, b_network, False)
             if subnet_ids:
                 b_network['subnets'] = subnet_ids
-            b_networks.append(self._fields(b_network, fields))
+            b_networks.append(db_utils.resource_fields(b_network, fields))
 
         if len(b_networks) == len(filters['id']):
             return b_networks
@@ -363,7 +367,7 @@ class TricirclePlugin(plugin.Ml2Plugin):
                 subnet_ids = self._ensure_subnet(context, network)
                 if subnet_ids:
                     b_network['subnets'] = subnet_ids
-                b_networks.append(self._fields(b_network, fields))
+                b_networks.append(db_utils.resource_fields(b_network, fields))
         return b_networks
 
     def create_subnet(self, context, subnet):
@@ -421,7 +425,7 @@ class TricirclePlugin(plugin.Ml2Plugin):
             b_subnet = self._create_bottom_subnet(t_ctx, context, t_subnet)
         if b_subnet['enable_dhcp']:
             self._ensure_subnet_dhcp_port(t_ctx, context, b_subnet)
-        return self._fields(b_subnet, fields)
+        return db_utils.resource_fields(b_subnet, fields)
 
     def get_subnets(self, context, filters=None, fields=None, sorts=None,
                     limit=None, marker=None, page_reverse=False):
@@ -440,7 +444,7 @@ class TricirclePlugin(plugin.Ml2Plugin):
         for b_subnet in b_full_subnets:
             if b_subnet['enable_dhcp']:
                 self._ensure_subnet_dhcp_port(t_ctx, context, b_subnet)
-            b_subnets.append(self._fields(b_subnet, fields))
+            b_subnets.append(db_utils.resource_fields(b_subnet, fields))
         if len(b_subnets) == len(filters['id']):
             return b_subnets
 
@@ -464,7 +468,7 @@ class TricirclePlugin(plugin.Ml2Plugin):
                 b_subnet = self._create_bottom_subnet(t_ctx, context, subnet)
                 if b_subnet['enable_dhcp']:
                     self._ensure_subnet_dhcp_port(t_ctx, context, b_subnet)
-                b_subnets.append(self._fields(b_subnet, fields))
+                b_subnets.append(db_utils.resource_fields(b_subnet, fields))
         return b_subnets
 
     def delete_subnet(self, context, _id):
@@ -738,8 +742,11 @@ class TricirclePlugin(plugin.Ml2Plugin):
             region_name = self._get_neutron_region()
             update_dict = {portbindings.PROFILE: {
                 t_constants.PROFILE_REGION: region_name,
-                t_constants.PROFILE_DEVICE: b_port['device_owner']
-                }}
+                t_constants.PROFILE_DEVICE: b_port['device_owner'],
+                portbindings.VIF_DETAILS: b_port[portbindings.VIF_DETAILS],
+                portbindings.VNIC_TYPE: b_port[portbindings.VNIC_TYPE],
+                portbindings.VIF_TYPE: b_port[portbindings.VIF_TYPE],
+                portbindings.HOST_ID: b_port[portbindings.HOST_ID]}}
             if b_port.get(t_constants.PROFILE_STATUS):
                 update_dict[portbindings.PROFILE].update({
                     t_constants.PROFILE_STATUS: b_port['status']
@@ -824,7 +831,7 @@ class TricirclePlugin(plugin.Ml2Plugin):
             b_port = self.core_plugin.create_port(context, {'port': t_port})
 
         self._ensure_trunk(context, t_ctx, _id)
-        return self._fields(b_port, fields)
+        return db_utils.resource_fields(b_port, fields)
 
     def get_ports(self, context, filters=None, fields=None, sorts=None,
                   limit=None, marker=None, page_reverse=False):
@@ -867,7 +874,7 @@ class TricirclePlugin(plugin.Ml2Plugin):
             port.pop('qos_policy_id', None)
             b_port = self.core_plugin.create_port(context,
                                                   {'port': port})
-            b_ports.append(self._fields(b_port, fields))
+            b_ports.append(db_utils.resource_fields(b_port, fields))
         return b_ports
 
     def delete_port(self, context, _id, l3_port_check=True):
@@ -889,6 +896,8 @@ class TricirclePlugin(plugin.Ml2Plugin):
     def _handle_security_group(self, t_ctx, q_ctx, port):
         if 'security_groups' not in port:
             return
+        if port.get('device_owner') and net.is_port_trusted(port):
+            return
         if not port['security_groups']:
             raw_client = self.neutron_handle._get_client(t_ctx)
             params = {'name': 'default'}
@@ -952,3 +961,23 @@ class TricirclePlugin(plugin.Ml2Plugin):
                 b_sgs.append(self.core_plugin.get_security_group(
                     context, b_sg['id'], fields))
         return b_sgs
+
+    def _handle_segment_change(self, rtype, event, trigger, context, segment):
+
+        network_id = segment.get('network_id')
+
+        if event == events.PRECOMMIT_CREATE:
+            updated_segment = self.type_manager.reserve_network_segment(
+                context, segment)
+            # The segmentation id might be from ML2 type driver, update it
+            # in the original segment.
+            segment[api.SEGMENTATION_ID] = updated_segment[api.SEGMENTATION_ID]
+        elif event == events.PRECOMMIT_DELETE:
+            self.type_manager.release_network_segment(context, segment)
+
+        # change in segments could affect resulting network mtu, so let's
+        # recalculate it
+        network_db = self._get_network(context, network_id)
+        network_db.mtu = self._get_network_mtu(
+            network_db, validate=(event != events.PRECOMMIT_DELETE))
+        network_db.save(session=context.session)
