@@ -12,13 +12,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from openstack import service_description
 from openstack import service_filter
 
+from tricircle.tests.tricircle_sdk.v1 import _proxy
 
-class MultiregionNetworkService(service_filter.ServiceFilter):
+
+class MultiregionNetworkService(service_description.ServiceDescription):
     valid_versions = [service_filter.ValidVersion('v1')]
+    proxy_class = _proxy.Proxy
 
     def __init__(self, version=None):
         # TODO(zhiyuan) register a proper service type in keystone
         super(MultiregionNetworkService, self).__init__(
-            service_type='tricircle', version=version)
+            service_type='tricircle_sdk')
